FeedController class

Controller for the simple multi feed. Holds a nested Page, Tab and Scroll controllers

Inheritance

Constructors

FeedController({double? initialOffset, bool? keepScrollOffset, String? debugLabel, FeedGridViewDelegate? gridDelegate})
Default constructor Creates the nested controllers
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addItem(dynamic item) → void
Adds an item to the beginning of the stated multi feed
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
clear() → void
Clears the feed
dispose() → void
Discards any resources used by the object.
override
getGridDelegate() → FeedGridViewDelegate?
Retrieves the grid delegate at the index
hasMore() → bool
Retrieves the list of items from the feed
isBinded() → bool
isGridIndex() → bool
Determines if the current index is a grid view
isNotRefreshed() → bool
Determines if an index has been refreshed
list() → List
Retrieves the list of items from the feed
loading() → bool
Determines if the feed is loading
loadMore() → Future<void>
Loads the next page of the feed
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
pageToken() → String?
Retrieves the list of feed token
reload() → Future<void>
Reloads the feed state based on the original size parameter
removeItem(String item, {RetrievalFunction? retrievalFunction}) → void
Removes an item from all the feeds
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
scrollController() → ScrollController
Reloads the feed state based on the original size parameter
setState(InitialFeedState state) → void
Adds an item to the beginning of the stated multi feed
size() → int
Retrieves the length of the list of items from the feed
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited