FeedGridViewDelegate class

The specification for a gridview, if passed into the feed, transforms it into a grid feed

Constructors

FeedGridViewDelegate({int crossAxisCount = 2, double mainAxisSpacing = 8, double crossAxisSpacing = 8, EdgeInsets padding = EdgeInsets.zero})

Properties

crossAxisCount → int
final
crossAxisSpacing → double
final
hashCode → int
The hash code for this object.
no setterinherited
mainAxisSpacing → double
final
padding → EdgeInsets
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited