MultiFeedController class

Constructors

MultiFeedController({required int pageCount, FeedGridViewDelegate? gridDelegatesAtIndex(int index)?})

Properties

hashCode → int
The hash code for this object.
no setterinherited
pageCount → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

controllerAt(int index) → FeedController
isBinded(int index) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeItem(String item, {RetrievalFunction? retrievalFunction}) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited